@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -37,8 +37,8 @@
 using namespace KAddressBookGrantlee;
 
 ContactGrantleePrintObject::ContactGrantleePrintObject(const KContacts::Addressee &address, QObject *parent)
-    : QObject(parent),
-      mAddress(address)
+    : QObject(parent)
+    , mAddress(address)
 {
     const auto addresses = address.addresses();
     mListAddress.reserve(addresses.size());
@@ -66,7 +66,7 @@ ContactGrantleePrintObject::ContactGrantleePrintObject(const KContacts::Addresse
 
     const QStringList customs = mAddress.customs();
     for (const QString &custom : customs) {
-        if (custom.startsWith(QStringLiteral("messaging/"))) {
+        if (custom.startsWith(QLatin1String("messaging/"))) {
             const int pos = custom.indexOf(QLatin1Char(':'));
             QString key = custom.left(pos);
             key.remove(QStringLiteral("-All"));
@@ -283,9 +283,9 @@ QString ContactGrantleePrintObject::logo() const
 QString ContactGrantleePrintObject::anniversary() const
 {
     const QDate anniversary = QDate::fromString(mAddress.custom(QStringLiteral("KADDRESSBOOK"),
-                              QStringLiteral("X-Anniversary")), Qt::ISODate);
+                                                                QStringLiteral("X-Anniversary")), Qt::ISODate);
     if (anniversary.isValid()) {
-        return (QLocale().toString(anniversary));
+        return QLocale().toString(anniversary);
     }
     return QString();
 }
